AbsorbedDose

Struct AbsorbedDose 

pub struct AbsorbedDose(/* private fields */);
An absorbed radiation dose quantity, stored internally in grays (Gy).

Construction

let dose = AbsorbedDose::from_mgy(50.0);

Implementations

Source

impl AbsorbedDose

pub const fn from_gy(val: f64) -> Self

Create from grays (canonical unit).

pub const fn from_mgy(val: f64) -> Self

Create from milligrays. 1 mGy = 1e-3 Gy.

pub const fn from_ugy(val: f64) -> Self

Create from micrograys. 1 uGy = 1e-6 Gy.

pub const fn from_rad_dose(val: f64) -> Self

Create from rads. 1 rad = 0.01 Gy.

pub const fn in_gy(self) -> f64

Get value in grays.

pub const fn in_mgy(self) -> f64

Get value in milligrays.

pub const fn in_ugy(self) -> f64

Get value in micrograys.

pub const fn in_rad_dose(self) -> f64

Get value in rads.

pub fn in_unit(self, unit: AbsorbedDoseUnit) -> f64

Get value in the specified AbsorbedDoseUnit.

pub fn display_as(self, unit: AbsorbedDoseUnit) -> DisplayWithUnit

Return a display wrapper that formats this dose in the given unit.

pub fn abs(self) -> Self

Return the absolute value of this absorbed dose.