pub struct Angle(/* private fields */);Expand description
A plane angle, stored canonically in radians.
Construction
use space_units::Angle;
let a = Angle::from_deg(90.0);
let b = Angle::from_rad(std::f64::consts::FRAC_PI_2);With the NumericExt trait in scope:
use space_units::{Angle, NumericExt as _};
let a = 90.0.deg();
let b = (std::f64::consts::FRAC_PI_2).rad();Typed arithmetic
| Expression | Result |
|---|---|
Angle / Time | AngularVelocity |
Implementations
Sourceimpl Angle
impl Angle
Sourcepub const fn from_arcmin(val: f64) -> Self
pub const fn from_arcmin(val: f64) -> Self
Creates an angle from a value in arc-minutes.
Sourcepub const fn from_arcsec(val: f64) -> Self
pub const fn from_arcsec(val: f64) -> Self
Creates an angle from a value in arc-seconds.
Sourcepub const fn from_hour_angle(val: f64) -> Self
pub const fn from_hour_angle(val: f64) -> Self
Creates an angle from a value in hour angles.
Sourcepub const fn in_hour_angle(self) -> f64
pub const fn in_hour_angle(self) -> f64
Returns the angle in hour angles.
Sourcepub fn display_as(self, unit: AngleUnit) -> DisplayWithUnit
pub fn display_as(self, unit: AngleUnit) -> DisplayWithUnit
Returns a display wrapper that formats the angle in the specified unit.