AngularAcceleration

Struct AngularAcceleration 

pub struct AngularAcceleration(/* private fields */);
An angular acceleration, stored canonically in rad/s².

Construction

use space_units::AngularAcceleration;

let alpha = AngularAcceleration::from_radps2(0.5);
let alpha2 = AngularAcceleration::from_degps2(30.0);

Typed arithmetic

Implementations

Source

impl AngularAcceleration

pub const fn from_radps2(val: f64) -> Self

Creates an angular acceleration from a value in radians per second squared.

pub const fn from_degps2(val: f64) -> Self

Creates an angular acceleration from a value in degrees per second squared.

pub const fn from_revps2(val: f64) -> Self

Creates an angular acceleration from a value in revolutions per second squared.

pub const fn in_radps2(self) -> f64

Returns the angular acceleration in radians per second squared.

pub const fn in_degps2(self) -> f64

Returns the angular acceleration in degrees per second squared.

pub const fn in_revps2(self) -> f64

Returns the angular acceleration in revolutions per second squared.

pub fn in_unit(self, unit: AngularAccelerationUnit) -> f64

Returns the angular acceleration in the specified AngularAccelerationUnit.

pub fn display_as(self, unit: AngularAccelerationUnit) -> DisplayWithUnit

Returns a display wrapper that formats the angular acceleration in the specified unit.

pub fn abs(self) -> Self

Returns the absolute value of the angular acceleration.