AngularMomentum

Struct AngularMomentum 

pub struct AngularMomentum(/* private fields */);
An angular momentum, stored canonically in newton-metre-seconds (Nms).

Construction

use space_units::AngularMomentum;

let l = AngularMomentum::from_n_m_s(42.0);

Implementations

Source

impl AngularMomentum

pub const fn from_n_m_s(val: f64) -> Self

Creates an angular momentum from a value in newton-metre-seconds.

pub const fn in_n_m_s(self) -> f64

Returns the angular momentum in newton-metre-seconds.

pub const fn display_as(self, unit: AngularMomentumUnit) -> DisplayWithUnit

Returns a display wrapper that formats the angular momentum in the specified unit.

pub fn abs(self) -> Self

Returns the absolute value of the angular momentum.