pub struct AngularVelocity(/* private fields */);Expand description
An angular velocity (rate of rotation), stored canonically in rad/s.
Construction
use space_units::AngularVelocity;
let w = AngularVelocity::from_rpm(3600.0);
let w2 = AngularVelocity::from_radps(1.0);Typed arithmetic
| Expression | Result |
|---|---|
AngularVelocity * Time | Angle |
AngularVelocity / Time | AngularAcceleration |
Implementations
Sourceimpl AngularVelocity
impl AngularVelocity
Sourcepub const fn from_radps(val: f64) -> Self
pub const fn from_radps(val: f64) -> Self
Creates an angular velocity from a value in radians per second.
Sourcepub const fn from_degps(val: f64) -> Self
pub const fn from_degps(val: f64) -> Self
Creates an angular velocity from a value in degrees per second.
Sourcepub const fn from_rpm(val: f64) -> Self
pub const fn from_rpm(val: f64) -> Self
Creates an angular velocity from a value in revolutions per minute.
Sourcepub const fn from_revps(val: f64) -> Self
pub const fn from_revps(val: f64) -> Self
Creates an angular velocity from a value in revolutions per second.
Sourcepub fn in_unit(self, unit: AngularVelocityUnit) -> f64
pub fn in_unit(self, unit: AngularVelocityUnit) -> f64
Returns the angular velocity in the specified AngularVelocityUnit.
Sourcepub fn display_as(self, unit: AngularVelocityUnit) -> DisplayWithUnit
pub fn display_as(self, unit: AngularVelocityUnit) -> DisplayWithUnit
Returns a display wrapper that formats the angular velocity in the specified unit.