DoseEquivalent

Struct DoseEquivalent 

pub struct DoseEquivalent(/* private fields */);
A dose equivalent quantity, stored internally in sieverts (Sv).

Construction

let eq = DoseEquivalent::from_msv(1.0);

Implementations

Source

impl DoseEquivalent

pub const fn from_sv(val: f64) -> Self

Create from sieverts (canonical unit).

pub const fn from_msv(val: f64) -> Self

Create from millisieverts. 1 mSv = 1e-3 Sv.

pub const fn from_usv(val: f64) -> Self

Create from microsieverts. 1 uSv = 1e-6 Sv.

pub const fn from_rem(val: f64) -> Self

Create from rem. 1 rem = 0.01 Sv.

pub const fn in_sv(self) -> f64

Get value in sieverts.

pub const fn in_msv(self) -> f64

Get value in millisieverts.

pub const fn in_usv(self) -> f64

Get value in microsieverts.

pub const fn in_rem(self) -> f64

Get value in rem.

pub fn in_unit(self, unit: DoseEquivalentUnit) -> f64

Get value in the specified DoseEquivalentUnit.

pub fn display_as(self, unit: DoseEquivalentUnit) -> DisplayWithUnit

Return a display wrapper that formats this dose equivalent in the given unit.

pub fn abs(self) -> Self

Return the absolute value of this dose equivalent.