Resistance

Struct Resistance 

pub struct Resistance(/* private fields */);
An electrical resistance quantity, stored internally in ohms (Ohm).

Construction

let r = Resistance::from_kohm(4.7);

Typed arithmetic

Implementations

Source

impl Resistance

pub const fn from_ohm(val: f64) -> Self

Create from ohms (canonical unit).

pub const fn from_mohm(val: f64) -> Self

Create from milliohms. 1 mOhm = 1e-3 Ohm.

pub const fn from_kohm(val: f64) -> Self

Create from kilohms. 1 kOhm = 1e3 Ohm.

pub const fn from_megaohm(val: f64) -> Self

Create from megaohms. 1 MOhm = 1e6 Ohm.

pub const fn in_ohm(self) -> f64

Get value in ohms.

pub const fn in_mohm(self) -> f64

Get value in milliohms.

pub const fn in_kohm(self) -> f64

Get value in kilohms.

pub const fn in_megaohm(self) -> f64

Get value in megaohms.

pub fn in_unit(self, unit: ResistanceUnit) -> f64

Get value in the specified ResistanceUnit.

pub fn display_as(self, unit: ResistanceUnit) -> DisplayWithUnit

Return a display wrapper that formats this resistance in the given unit.

pub fn abs(self) -> Self

Return the absolute value of this resistance.