SolidAngle

Struct SolidAngle 

pub struct SolidAngle(/* private fields */);
A solid angle (two-dimensional angular span), stored canonically in steradians (sr).

Construction

use space_units::SolidAngle;

let omega = SolidAngle::from_sr(2.0);
let omega2 = SolidAngle::from_deg2(100.0);
let full_sphere = SolidAngle::from_spat(1.0);

Implementations

Source

impl SolidAngle

pub const fn from_sr(val: f64) -> Self

Creates a solid angle from a value in steradians.

pub const fn from_deg2(val: f64) -> Self

Creates a solid angle from a value in square degrees.

pub const fn from_spat(val: f64) -> Self

Creates a solid angle from a value in spats (full spheres).

pub const fn in_sr(self) -> f64

Returns the solid angle in steradians.

pub const fn in_deg2(self) -> f64

Returns the solid angle in square degrees.

pub const fn in_spat(self) -> f64

Returns the solid angle in spats (full spheres).

pub fn in_unit(self, unit: SolidAngleUnit) -> f64

Returns the solid angle in the specified SolidAngleUnit.

pub fn display_as(self, unit: SolidAngleUnit) -> DisplayWithUnit

Returns a display wrapper that formats the solid angle in the specified unit.

pub fn abs(self) -> Self

Returns the absolute value of the solid angle.